#
# spec file for package ffado-mixer
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           ffado-mixer
%define tname libffado
Version:        2.2.1
Release:        3.2
Summary:        FireWire 1394 support for audio devices, svn snapshot
License:        GPL-2.0+
Group:          Productivity/Multimedia/Other
Url:            http://www.ffado.org/
Source0:        %{tname}-%{version}.tar.bz2
Patch1:         ffado_SConstruct_powerpc_update.patch
Patch2:         ffado-gcc6.patch
BuildRequires:  alsa-devel
BuildRequires:  dbus-1-python-devel
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  ffado
BuildRequires:  gcc-c++
BuildRequires:  graphviz-gnome
BuildRequires:  libavc1394-devel
BuildRequires:  libconfig++-devel
BuildRequires:  libdbus-c++-devel
BuildRequires:  libexpat-devel
BuildRequires:  libiec61883-devel >= 1.1.0
BuildRequires:  libqt4-devel
BuildRequires:  libraw1394-devel >= 1.3.0
BuildRequires:  pkg-config
BuildRequires:  python-qt4-devel
Requires:       python-qt4
BuildRequires:  scons
BuildRequires:  update-desktop-files
BuildRequires:  xdg-utils
BuildRequires:  xorg-x11-fonts
BuildRequires:  pkgconfig(dbus-1) >= 1.0
BuildRequires:  pkgconfig(libxml++-2.6) >= 2.13.0
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
%{py_requires}

%description
FFADO aims to provide a generic, open-source solution
to support FireWire(IEEE1394, iLink) based (semi-)
professional audio interfaces.
It's the successor of the FreeBoB project. FFADO is a
volunteer-based community effort, trying to provide Linux
with at least the same level of functionality that is
present on the other operating systems.
The range of FireWire Audio Devices that we would like
to support is broad: from pure audio interfaces over
mixed audio-control devices to DSP algorithm devices.
This is a snapshot of svn revision 2040

%package -n ffado-doc
Summary:        API documentation for ffado
Group:          Documentation/HTML
BuildArch:      noarch

%description -n ffado-doc
This package contains the libffado API documentation.

%prep
%setup -n %{tname}-%{version} -q
%patch1 -p1
%patch2

%build
scons %{?jobs:--jobs=%jobs} \
  PREFIX=%{_prefix} \
  LIBDIR=%{_libdir} \
  MANDIR=%{_mandir} \
  ENABLE_GENERICAVC=yes \
  SERIALIZE_USE_EXPAT=no \
  DEBUG=no \
  ENABLE_ALL=yes \
  PYPKGDIR=%{python_sitelib} \
  ENABLE_OPTIMIZATIONS=yes \
  BUILD_TESTS=yes \
  COMPILE_FLAGS="%{optflags} -fno-strict-aliasing -ggdb --std=gnu++11"

%install
scons   DESTDIR=%{buildroot} \
  install

# Build API documentation
export top_srcdir=$PWD
pushd doc
doxygen -u reference.doxygen.in
doxygen reference.doxygen.in
mkdir -p %{buildroot}%{_docdir}/%{tname}
cp -r reference %{buildroot}%{_docdir}/%{tname}
popd

mv %{buildroot}%{_datadir}/%{tname}/icons %{buildroot}%{_datadir}/
rm %{buildroot}%{_libdir}/%tname.*
rm -r %{buildroot}%{_includedir}/libffado
rm -r %{buildroot}%{_libdir}/pkgconfig

# Remove the useless udev rules and man pages on the mixer package
rm -r %{buildroot}%{_mandir}
rm -r %{buildroot}/lib

rpm -ql ffado | while read file; do
  rm -v "%{buildroot}$file" || true
done

mkdir -p %{buildroot}%{_datadir}/applications/
 mkdir -p %{buildroot}%{_datadir}/pixmaps
 cp support/xdg/hi64-apps-ffado.png %{buildroot}%{_datadir}/pixmaps/ffadomixer.png
%suse_update_desktop_file -c ffadomixer FfadoMixer "Mixer for ffado" ffado-mixer ffadomixer "AudioVideo;Mixer;HardwareSettings;Qt"

# This problem seems to have been fixed in svn builds
%if 0 == 1
chmod 755 %{buildroot}%{_datadir}/%{tname}/python/ffado_configuration.py
chmod 755 %{buildroot}%{_datadir}/%{tname}/python/ffado_panelmanager.py
chmod 755 %{buildroot}%{_datadir}/%{tname}/python/ffado_dbus_util.py
%endif

find ./ -empty -delete
%fdupes -s %{buildroot}%{_datadir}

%files
%defattr(-,root,root)
%doc README AUTHORS ChangeLog LICENSE.GPLv2 LICENSE.GPLv3
%{_bindir}/ffado-mixer
%{_datadir}/%{tname}/
%{_datadir}/icons/*
%{_datadir}/pixmaps/ffadomixer.png
%{_datadir}/applications/*
%{python_sitelib}/*

%files -n ffado-doc
%defattr(-,root,root)
%{_docdir}/%{tname}

%changelog
* Wed Mar  2 2016 dimstar@opensuse.org
- Add --std=gnu++11 to COMPILE_FLAGS.
* Wed Mar  2 2016 dimstar@opensuse.org
- Replace libxmll++-devel BuildRequires with
  pkgconfig(libxml++-2.6) in order to be ready for the
  compatibility package introduction (libxml++ goes 3.0).
* Mon Feb  8 2016 rguenther@suse.com
- Add ffado-gcc6.patch to move #include <math.h> outside of a namespace
  and to not declare errno as local variable.
* Sat Jul  4 2015 bwiedemann@suse.com
- require python-qt4 at runtime (bnc#937060)
* Wed Mar 11 2015 normand@linux.vnet.ibm.com
- SConstruct is_powerpc and is_64bit to support ppc64le
  with new ffado_SConstruct_powerpc_update.patch
* Sun Sep 21 2014 davejplater@gmail.com
- Update to version 2.2.1, no mixer changes.
* Thu Sep 18 2014 fcrozat@suse.com
- Drop subversion BuildRequires, not needed at all.
* Mon Dec 24 2012 p.drouand@gmail.com
- Update to 2.1.0 version:
  * Significantly improved support for the new "juju" firewire stack
    found in newer kernels
  * Support for JACK freewheeling mode and set-buffer-size operation
  * Lower CPU usage
  * udev rules included in FFADO to give user access to audio device files
  * More stable streaming
  * Fix crash when realtime system clock was set
  * Fix race conditions and invalid memory accesses on shutdown
  * Fixes for clean compilation on recent gcc versions (up to 4.7)
  * ffado-diag enhanced to aid debugging efforts
  * Many bugs fixed
- Remove patchs merged on upstream release:
  * ffado-gcc47.patch
  * libffado-bswap.patch
- Do not use and include ChangeLog in the package because the svn repo is down
  and this file could not be update
- Remove useless conditional macros
* Wed Jun 27 2012 dvaleev@suse.com
- fix ppc64 build
* Tue Mar 13 2012 davejplater@gmail.com
- Changed build to noarch as suggested by rpmlint
* Thu Mar  1 2012 davejplater@gmail.com
- Update to version 2.0.1.2040
- ffado-dbus-server added
- See ffado's changelog
* Tue Nov  2 2010 coolo@novell.com
- move doc generation into 2nd spec file
* Tue Nov  2 2010 davejplater@gmail.com
- Fix some rpmlint errors
* Mon Nov  1 2010 coolo@novell.com
- remove qt dependency, splitted into ffado-mixer spec file
* Thu Sep 30 2010 davejplater@gmail.com
- Update to version 2.0.1
- Upstream changes :-
  Make it work on the new firewire-stack.
  Of course some more fixes went into the package. But its mostly
  intended for distributors so they can finally deprecate/disable the
  old firewire stack in kernels.
  For more changelog and instructions please look back at the 2.0.0
  release announcement http://www.ffado.org/?q=release/2.0.0
* Wed Jun 16 2010 davejplater@gmail.com
- Update to svn 1856.
- Upstream changes : Make it easier for distributions to define
  their own additional built-flags.
  Numerous bug fixes, see ChangeLog for details.
* Fri Apr 30 2010 davejplater@gmail.com
- Created package ffado version 2.0.0
